<?php

class BudovaController extends Controller
{
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('budova','zobraz','postav'),
				'users'=>array('@'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

        // ----------------------------------
        // Akce kontroléru
        // ----------------------------------
        public function actionBudova()
        {
		$this->render('budova');
        }
        
        public function actionPostav() {
                
		if(!empty($_POST))
		{   
                    foreach ($_POST as $index => $value) {
                        if(is_integer($index)){
                            $this->ulozDoDB($index, $_POST['type'], abs($value));
                            $this->zvetsiMax(Yii::app()->session['ID_Mesta'], $_POST['type'], $value);
                            $this->actionZobraz($_POST['type']);
                        }
                    }                    
		}  else {
                  $this->render('budova');  
                }
		
        }
        
        public function actionZobraz($id)
	{
                $budova = $this->najdiBudovu($id);
                $cenik = $this->zjistiCenu($id);
                $max = $this->Maximum($id);
                $vlastnim = $this->vlastnimBudov($id);
                $this->renderPartial('zobraz',array('budova'=>$budova, 'cenik'=> $cenik, 'max'=>$max, 'vlastnim'=>$vlastnim));
        }
        
        
        // ----------------------------------
        // Pomocné funkce
        // ----------------------------------
        /**
         *  Zvětší maximální hranice při postavení konkrétních budov
         * @param type $id_mesta
         * @param type $co
         * @param type $val
         */
        private function zvetsiMax($id_mesta,$co, $val) {
                $model = Mesto::model()->findByAttributes(array('Id_mesto'=>$id_mesta));           
                switch ($co) {
                    case 1: //dům musím zvětšit max lidi
                            $model->Max_lidi = $model->Max_lidi + (10*$val);
                            Yii::app()->session['max_lidi'] = $model->Max_lidi;
                            break;
                    case 4: //kasarna musím zvětšit max vojaku
                            $model->Max_vojska = $model->Max_vojska + (10*$val);
                            Yii::app()->session['max_vojska'] = $model->Max_vojska;
                            break;
                    case 6: //sklad musím zvětšit max surovin
                            $model->Max_surovin = $model->Max_surovin + (10*$val);
                            Yii::app()->session['max_surovin'] = $model->Max_surovin;
                            break;
                            }  
                $model->save();     
        }
        
        /**
         * Načtení konkrétního modelu dle ID
         * @param type $id
         * @return type
         * @throws CHttpException
         */
        public function loadModel($id)
	{
		$model=Budova::model()->findByPk($id);
		if ($model === null) {
            throw new CHttpException(404, 'Požadovaná stránka neexistuje.');
        }
        return $model;
	}
        
        /**
         * Fce sloužící k uložení budov do DB po zakoupení
         * @param type $id  id budovy
         * @param type $typ typ budovy
         * @param type $val počet nových budov
         */
        private function ulozDoDB($id,$typ,$val) {
            if ($val <= $this->Maximum($typ)) {
                $vlastnim = $this->vlastnimBudov($typ);
                $own = $vlastnim['Pocet_budov'];
                $model=$this->loadModel($id);
                $model->Pocet_budov = $val + $own;
                $model->save();

                $cena = $this->zjistiCenu($typ);        
                foreach ($cena as $cena_budovy) {
                // když je složená z více surovin procházím každou zvlášť
                // a ověřuji jestli mám dostatek na stavěné budovy
                    $Surovina = $cena_budovy['Id_suroviny'];
                    $Cena_na_surovinu = $cena_budovy['Pocet'];
                    $zustatek = $this->aktualniSklad($Surovina);
                    $pocet = $zustatek -($val * $Cena_na_surovinu);
                    $this->odecti_zdroje(Yii::app()->session['ID_Mesta'], $Surovina, $pocet);
                }
                $puvodni = $this->najdiBudovu($typ);
                $prostor = Yii::app()->session['zabrany_prostor'] + ($val * $puvodni['Prostor']);
                $this->upravMisto(Yii::app()->session['ID_Mesta'], $prostor);
            }
        }
        
        /**
         *  Fce sloužící pro přepočet zastavěného místa ve městě
         * @param type $id_mesta    id města
         * @param type $hodnota     nová hodnota zastavěnosti
         */
        private function upravMisto($id_mesta, $hodnota) {
                $model = Mesto::model()->findByAttributes(array('Id_mesto'=>$id_mesta));
                $model->Misto = $hodnota;
                $model->save();
                Yii::app()->session['zabrany_prostor'] = $hodnota;
        }
        
        /**
         *  Fce sloužící pro odečtení suroviny ze skladu
         * @param type $id_mesta
         * @param type $id_suroviny
         * @param type $surovina    počet surovin po odečtu
         */
        private function odecti_zdroje($id_mesta, $id_suroviny ,$surovina) {
             $model = Sklad::model()->findByAttributes(array('Id_mesto'=>$id_mesta, 'Id_suroviny'=>$id_suroviny));
             $model->Pocet = $surovina;
             $model->save();
        } 
        
        /**
         * Zjištění volného místa pro stavění
         * @return type vrací volné místo ve městě
         */
        private function volneMisto(){
            // celkový volný prostor
            $Celkovy_prostor = Yii::app()->session['max_prostoru'] - Yii::app()->session['zabrany_prostor'];
            return $Celkovy_prostor;
        }
        
        /**
         * Zjištění maxilního možného počtu pro stavění budov
         * @param type $id id typ budovy
         * @return type vrací číslo s maximem pro konkrétní typ budovy
         */
        private function Maximum($id){
            $Celkovy_prostor = $this->volneMisto();
            // max budov limitován prostorem
            $puvodni = $this->najdiBudovu($id);
            $value = (int) $Celkovy_prostor / $puvodni['Prostor'];
                //načtu si cenu budovy
            $cena = $this->zjistiCenu($id);

            foreach ($cena as $cena_budovy) {
            // když je složená z více surovin procházím každou zvlášť
            // a ověřuji jestli mám dostatek na stavěné budovy
                $Surovina = $cena_budovy['Id_suroviny'];
                $Cena_na_surovinu = $cena_budovy['Pocet'];
                $zustatek = $this->aktualniSklad($Surovina);  
        
                if (($Cena_na_surovinu) < $zustatek) {
                    // když mám zdroje postavím jen ty na který mám
                    $valueT = (int) ($zustatek / $Cena_na_surovinu);
                    $value = $this->jeMensi($valueT, $value);
                } else {
                    $valueT = (int) ($zustatek / $Cena_na_surovinu);
                    $value = $this->jeMensi($valueT, $value);
                }
            }
            return (int) $value;
        }
    
        /**
         * Kontrolní fce, zdali je Temp Value menší než Valu předchozí
         * @param type $vT temp value
         * @param type $v  value
         * @return type vrací menší value
         */
        private function jeMensi($vT,$v) {
            if ($vT < $v) {$v = $vT;}
            return $v;
        }

        /**
         * Zjištění aktuálního počtu suroviny
         * @param type $Surovina
         * @return type
         */
        private function aktualniSklad($Surovina){
            $aktualni_sklad = Sklad::model()->findByAttributes(array('Id_mesto'=>Yii::app()->session['ID_Mesta'], 'Id_suroviny'=>$Surovina));
            return $aktualni_sklad['Pocet'];
        }

        /**
         *  Najde informace o konkrétním typu budovy
         * @param type $id
         * @return type
         */
        private function najdiBudovu($id) {
            $budova = TypBudovy::model()->findByAttributes( array('Id_typ'=>$id));
            return $budova->attributes;
        }
        
        /**
         * Vrací cenu konktrétního typu budovy
         * @param type $id
         * @return type
         */
        private function zjistiCenu($id) {
                    $cenik = CenaBudov::model()->with('suroviny')->findAllByAttributes(array('Id_typ_budovy'=>$id));
            return $cenik;
        }
        
        /**
         * Vrací počet vlastněných budov jednoto typu
         * @param type $id
         * @return type
         */
        private function vlastnimBudov($id) {
            $budova = Budova::model()->findByAttributes( array('Typ_budovy'=>$id,'Id_mesto'=>Yii::app()->session['ID_Mesta']));
            return $budova->attributes;
        }
}