<?php

class CenaJednotekController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('delete'),
                'roles' => array('1'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('index', 'create', 'admin', 'view', 'update'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {
            $this->render('view', array(
                'model' => $this->loadModel($id),
            ));
        } else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {
            $model = new CenaJednotek;

            // Uncomment the following line if AJAX validation is needed
            // $this->performAjaxValidation($model);

            if (isset($_POST['CenaJednotek'])) {
                $model->attributes = $_POST['CenaJednotek'];
                if ($model->save())
                    $this->redirect(array('view', 'id' => $model->id));
            }

            $this->render('create', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {

            $model = $this->loadModel($id);

            // Uncomment the following line if AJAX validation is needed
            // $this->performAjaxValidation($model);

            if (isset($_POST['CenaJednotek'])) {
                $model->attributes = $_POST['CenaJednotek'];
                if ($model->save())
                    $this->redirect(array('view', 'id' => $model->id));
            }

            $this->render('update', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {

            $this->loadModel($id)->delete();

            // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {

            $model = new CenaJednotek('search');
            $model->unsetAttributes();  // clear any default values
            if (isset($_GET['CenaJednotek']))
                $model->attributes = $_GET['CenaJednotek'];

            $this->render('admin', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        if (Yii::app()->session['PRAVA']['EditCena_Jednotek'] == '1') {

            $model = new CenaJednotek('search');
            $model->unsetAttributes();  // clear any default values
            if (isset($_GET['CenaJednotek']))
                $model->attributes = $_GET['CenaJednotek'];

            $this->render('admin', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return CenaJednotek the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = CenaJednotek::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CenaJednotek $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'cena-jednotek-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

}
