<?php

class JednotkaController extends Controller {

    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('jednotka', 'AjaxMaximum'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Akce Jednotka
     * Pokud je odeslaný formulář budou zakoupeny jednotky
     */
    public function actionJednotka() {
        if (!empty($_POST['yt0'])) {
            foreach ($_POST as $index => $value) {
                if (is_integer($index)) {
                    $this->UlozdoDB($index, $_POST[$index . '_t'], abs($value));
                }
            }
            $this->redirect(array('jednotka'));
        }
        $this->render('jednotka');
    }

    // ***************
    //  Pomocné funkce
    // ***************

    /**
     * 
     * @param type $id          Id konkrétní jednotky
     * @param type $typ         Id typu jednotky
     * @param type $value       Počet nově zakoupených jednotek
     */
    public function UlozdoDB($id, $typ, $value) {
        if ($value <= $this->Maximum($typ, 0, 0)) {

            $vlastnim = $this->vlastnimJednotek($typ);
            $own = $vlastnim['Pocet_jednotek'];
            $model = $this->loadModel($id);
            $model->Pocet_jednotek = $value + $own;
            $model->save();

            $cena = $this->zjistiCenu($typ);
            foreach ($cena as $cena_jednotky) {
                // když je složená z více surovin procházím každou zvlášť
                // a ověřuji jestli mám dostatek na najímané jednotky
                $Surovina = $cena_jednotky['Id_suroviny'];
                $Cena_na_surovinu = $cena_jednotky['Pocet'];
                $zustatek = $this->aktualniSklad($Surovina);
                $pocet = $zustatek - ($value * $Cena_na_surovinu);
                $this->odecti_zdroje(Yii::app()->session['ID_Mesta'], $Surovina, $pocet);
            }
            $puvodni = $this->najdiJednotku($typ);
            $prostor = Yii::app()->session['zabrany_prostor_kasarny'] + ($value * $puvodni['Pocet_mist']);
            $this->upravMisto(Yii::app()->session['ID_Mesta'], $prostor);
        }
    }

    /**
     * Načtení konkrétního modelu dle ID
     * @param type $id
     * @return type
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Jednotka::model()->findByPk($id);
        if ($model === null) {
            throw new CHttpException(404, 'Požadovaná stránka neexistuje.');
        }
        return $model;
    }

    /**
     * Funkce volaná AJAXem pro přepočítání maxima
     * @throws CHttpException
     */
    public function actionajaxMaximum() {
        if (isset($_POST['i'])) {
            $typJednotky = $_POST['i'];
            $zasoby = ($_POST['sklad']);
                echo $this->Maximum($typJednotky, $zasoby, 1);
        } else {
            throw new CHttpException(404, 'Něco se asi pokazilo :( ...');
        }
        Yii::app()->end();
    }

    /**
     * Zjištění maxima pro konkrétní typ jednotky
     * @param type $id          Id typu jednotky
     * @param type $SkladT      Dočasný sklad pokud je odesílánpřes AJAX
     * @param type $T           přepínač pro zjištění odesílaní ajaxu
     * @return type
     */
    public function Maximum($id, $SkladT, $T) {
        $Celkovy_prostor = $this->volneMisto();
        $puvodni = $this->najdiJednotku($id);
        // max vojáků limitován prostorem
        $value = (int) $Celkovy_prostor / $puvodni['Pocet_mist'];
        //načtu si cenu jednotky
        $cena = $this->zjistiCenu($id);
        foreach ($cena as $cena_jednotky) {
            // když je složená z více surovin procházím každou zvlášť
            // a ověřuji jestli mám dostatek na najímané jednotky
            $Surovina = $cena_jednotky['Id_suroviny'];
            $Cena_na_surovinu = $cena_jednotky['Pocet'];
            //pokud je z ajaxu vezmi dočasnej sklad
            if ($T == 1) {
                $zustatek = $SkladT[$Surovina];
            } else {
                $zustatek = $this->aktualniSklad($Surovina);
            }
            if (($Cena_na_surovinu) < $zustatek) {
                // když mám zdroje postavím jen ty na který mám
                $valueT = (int) ($zustatek / $Cena_na_surovinu);
                $value = $this->jeMensi($valueT, $value);
            } else {
                $valueT = (int) ($zustatek / $Cena_na_surovinu);
                $value = $this->jeMensi($valueT, $value);
            }
        }
        if($value < 0){$value = 0;}
        return (int) $value;
    }

    /**
     * Najde konkrétní jednotku dle typu
     * @param type $id  id typ jednotky
     * @return type
     */
    public function najdiJednotku($id) {
        $jednotka = TypJednotky::model()->findByAttributes(array('Id_typ' => $id));
        return $jednotka->attributes;
    }

    /**
     * Zjistí cenu konkrétní jednotky
     * @param type $id      id typ jednotky
     * @return type
     */
    private function zjistiCenu($id) {
        $cenik = CenaJednotek::model()->with('suroviny')->findAllByAttributes(array('Id_typ_jednotky' => $id));
        return $cenik;
    }

    /**
     * Zjistí volné místo v kasárně
     * @return type
     */
    private function volneMisto() {
        // celkový volný prostor
        $Celkovy_prostor = Yii::app()->session['max_vojska'] - Yii::app()->session['zabrany_prostor_kasarny'];
        return $Celkovy_prostor;
    }

    /**
     * Zajistí odečtení surovin ze skladu
     * @param type $id_mesta        Id města
     * @param type $id_suroviny     id suroviny který odečítáme
     * @param type $surovina        počet
     */
    public function odecti_zdroje($id_mesta, $id_suroviny, $surovina) {
        $model = Sklad::model()->findByAttributes(array('Id_mesto' => $id_mesta, 'Id_suroviny' => $id_suroviny));
        $model->Pocet = $surovina;
        $model->save();
    }

    /**
     * Porovnávací funkce
     * @param type $vT
     * @param type $v
     * @return type
     */
    private function jeMensi($vT, $v) {
        if ($vT < $v) {
            $v = $vT;
        }
        return $v;
    }

    /**
     * Upraví míst ov kasárně
     * @param type $id_mesta        id města
     * @param type $hodnota         hodnota na jakou upravuji
     */
    public function upravMisto($id_mesta, $hodnota) {
        $model = Mesto::model()->findByAttributes(array('Id_mesto' => $id_mesta));
        $model->Misto_kasarny = $hodnota;
        $model->save();
        Yii::app()->session['zabrany_prostor_kasarny'] = $hodnota;
    }

    /**
     * Zjištění aktuálního počtu suroviny ve skladu
     * @param type $Surovina    id suroviny
     * @return type
     */
    public function aktualniSklad($Surovina) {
        $aktualni_sklad = Sklad::model()->findByAttributes(array('Id_mesto' => Yii::app()->session['ID_Mesta'], 'Id_suroviny' => $Surovina));
        return $aktualni_sklad['Pocet'];
    }

    /**
     * Vrací počet vlastněných jednotek jednoto typu
     * @param type $id
     * @return type
     */
    private function vlastnimJednotek($id) {
        $budova = Jednotka::model()->findByAttributes(array('Typ_jednotky' => $id, 'Id_mesto' => Yii::app()->session['ID_Mesta']));
        return $budova->attributes;
    }

}
