<?php

class MestoController extends Controller {

    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('dokonceni', 'AjaxValidate'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Akce dokončující registraci uživatele
     * @return type
     * @throws CHttpException
     */
    public function actionDokonceni() {
        $model = new Mesto('dokonceni');
        if (isset($_POST['Mesto'])) {
            $model->attributes = $_POST['Mesto'];
            if ($model->validate()) {
                $model->Doba = 1;
                $model->Misto = 8;
                $model->Misto_kasarny = 0;
                $model->Max_surovin = 400;
                $model->Max_vojska = 0;
                $model->Max_lidi = 400;
                $model->Id_uzivatel = Yii::app()->session['ID1Log'];
                $souradnice = $this->vytvorSouradnice();
                $model->X_souradnice = $souradnice[0];
                $model->Y_souradnice = $souradnice[1];
                if ($model->save()) {
                    //Postavení budov
                    $this->postavBudovy($model->Id_mesto);
                    //Najmutí jednotek
                    $this->najmiJednotky($model->Id_mesto);
                    //Naplnění skladu
                    $this->naplSklad($model->Id_mesto);
                    //Uprava uzivatele
                    $this->upravUzivatele(Yii::app()->session['ID1Log'], $_POST['Mesto']['Heslo']);
                    //Odhlaseni zabití seasson + presmerovaíní + flashmessage
                    Yii::app()->session['ID1Log'] = "";
                    Yii::app()->user->setFlash('regComplete', 'Vaše registrace byla dokončena. Nyní se můžete přihlásit a užít si zábavu.');
                    $this->redirect(Yii::app()->request->baseUrl . '/site/index');
                }
                return;
            }
        }
        //Pokud se uživatel loguje poprvé    
        if (Yii::app()->session['ID1Log']) {
            $u = Uzivatel::model()->findByAttributes(array('Id_uzivatel' => Yii::app()->session['ID1Log']));
            if ($u->dokoncena_registrace == 0) {
                //pokud není dokončená registrace
                $this->render('dokonceni', array('model' => $model));
            }
        } else {
            throw new CHttpException(404, 'Požadovaná stránka nebyla nalezena!');
        }
    }
    
    /**
     * Validační funkce
     */
    public function actionAjaxValidate() {
        header("Content-Type: text/javascript");
        if (isset($_GET['Nazev'])) {
            switch ($_GET['s']) {
                case 1:
                    $nazev = htmlspecialchars($_GET['Nazev']);
                    $modelN = Mesto::model()->findByAttributes(array('Nazev' => $nazev));
                    if (isset($modelN)) {
                        echo "document.getElementById('ajaxN').innerHTML = 'Zadaný název již existuje. Zvolte prosím jiný.';";
                    } else {
                        echo "document.getElementById('ajaxN').innerHTML = '';";
                    }
                    break;
                case 0:
                    $nazev = htmlspecialchars($_GET['Nazev']);
                    $modelN = Mesto::model()->findByAttributes(array('Nazev' => $nazev));
                    if (isset($modelN)) {
                        echo "document.getElementById('ajaxN').innerHTML = 'Zadaný název již existuje. Zvolte prosím jiný.';";
                    } else {
                        echo "document.forms['uzivatel-dokonceni-form'].submit();\n";
                    }
                    break;
                default:
                    break;
            }
        } else {
            Yii::app()->end();
        }
    }

    // --------------------------
    // ---- Pomocné fce ---------
    //---------------------------
    
    /**
     * Upraví uživatele, heslo, Dokoncena registrace
     * @param type $idUziv  ID uživatele
     * @param type $pass    HEslo
     */
    private function upravUzivatele($idUziv, $pass) {
        $uzivatel = Uzivatel::model()->findByAttributes(array('Id_uzivatel' => $idUziv));
        $uzivatel->dokoncena_registrace = 1;
        $uzivatel->Heslo = $uzivatel->getHash($pass);
        $uzivatel->PREPINAC = 1;
        $uzivatel->save(false);
    }

    /**
     * Postaví budovy pro město
     * @param type $idMesta ID města
     */
    private function postavBudovy($idMesta) {
        for ($i = 1; $i <= 6; $i++) {
            $budova = new Budova();
            $budova->Id_mesto = $idMesta;
            $budova->Typ_budovy = $i;
            $budova->Pocet_budov = 1;
            $budova->save();
        }
    }

    /**
     * Najme základní jednotky pro město
     * @param type $idMesta ID město
     */
    private function najmiJednotky($idMesta) {
        for ($i = 1; $i <= 5; $i++) {
            $jednotka = new Jednotka();
            $jednotka->Id_mesto = $idMesta;
            $jednotka->Typ_jednotky = $i;
            $jednotka->Pocet_jednotek = 0;
            $jednotka->save();
        }
    }

    /**
     * Vytvoří základní suroviny ve skladu
     * @param type $idMesta
     */
    private function naplSklad($idMesta) {
        for ($i = 1; $i <= 5; $i++) {
            $sklad = new Sklad();
            $sklad->Id_mesto = $idMesta;
            $sklad->Id_suroviny = $i;
            $sklad->Pocet = 100;
            $sklad->save();
        }
    }

    /**
     * Fce vytvoří náhodné X a Y suřadnice
     * @return array vrací unikátní souřadnice
     */
    private function vytvorSouradnice() {
        $min = -50;
        $max = 50;

        $check = false;
        do {
            $x = rand($min, $max);
            $y = rand($min, $max);
            $query = Mesto::model()->findByAttributes(array('X_souradnice' => $x, 'Y_souradnice' => $y));

            if (empty($query->Id_mesto)) {
                $check = true;
            }
        } while ($check == false);
        $vys = array($x, $y);
        return $vys;
    }
}
