<?php

class PostaController extends Controller {

    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('prijate', 'zobraz', 'odeslane', 'smazat', 'nova', 'odpoved', 'index'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function actionPrijate() {
        // Filtrování pošty podle příjemců
        if (isset($_REQUEST['prezdivka'])) {
            Yii::app()->session['id_user_posta'] = $_POST['prezdivka'];
            $this->redirect('prijate');
        }
        // Stránkování pošty
        if (isset($_REQUEST['strankovani'])) {
            Yii::app()->session['strankovani'] = $_POST['strankovani'];
            $this->redirect('prijate');
        }

        $criteria = new CDbCriteria();
        $criteria->order = 'Id_zprava DESC';
        $criteria->with = array('odesilatel');
        // Když je zvolený filter načti pouze konktrétního uživatele
        if (Yii::app()->session['id_user_posta'] != "") {
            $criteria->condition = '(Id_odesilatele = :ido AND Id_prijemce = :idp) OR Typ_posty = 0 AND Smaz_prij = 0';
            $criteria->params = array(':ido' => Yii::app()->session['id_user_posta'], ':idp' => Yii::app()->user->id);
            //Když je filter vypnutý
        } else {
            $criteria->condition = '(Id_prijemce = :idp) OR Typ_posty = 0 AND Smaz_prij = 0';
            $criteria->params = array(':idp' => Yii::app()->user->id);
        }

        //Zjisti počet záznamů
        $count = Zprava::model()->count($criteria);
        //Nastav widget pro stránkování
        $pages = new CPagination($count);
        $pages->pageSize = Yii::app()->session['strankovani'];
        $pages->applyLimit($criteria);
        //Načti data z DB
        $textZpravy = Zprava::model()->findAll($criteria);
        $this->render('prijate', array('textZpravy' => $textZpravy, 'pages' => $pages, 'count' => $count, 'pageSize' => $pages->pageSize));
    }
    
    
    

    public function actionIndex() {
        $this->redirect('prijate');
    }

    public function actionOdeslane() {
        // Filtrování pošty podle příjemců
        if (isset($_REQUEST['prezdivka'])) {
            Yii::app()->session['id_user_postaOd'] = $_POST['prezdivka'];
            $this->redirect('odeslane');
        }
        // Stránkování pošty
        if (isset($_REQUEST['strankovani'])) {
            Yii::app()->session['strankovani'] = $_POST['strankovani'];
            $this->redirect('odeslane');
        }

        $criteria = new CDbCriteria();
        $criteria->order = 'Id_zprava DESC';
        $criteria->with = array('prijemce');
        // Když je zvolený filter načti pouze konktrétního uživatele
        if (Yii::app()->session['id_user_postaOd'] != "") {
            $criteria->condition = 'Id_odesilatele = :ido AND Id_prijemce = :idp AND Smaz_odes = 0';
            $criteria->params = array(':idp' => Yii::app()->session['id_user_postaOd'], ':ido' => Yii::app()->user->id);
            //Když je filter vypnutý
        } else {
            $criteria->condition = 'Id_odesilatele = :ido AND Smaz_odes = 0';
            $criteria->params = array(':ido' => Yii::app()->user->id);
        }

        //Zjisti počet záznamů
        $count = Zprava::model()->count($criteria);
        //Nastav widget pro stránkování
        $pages = new CPagination($count);
        $pages->pageSize = Yii::app()->session['strankovani'];
        $pages->applyLimit($criteria);
        //Načti data z DB
        $textZpravy = Zprava::model()->findAll($criteria);
        $this->render('odeslane', array('textZpravy' => $textZpravy, 'pages' => $pages, 'count' => $count, 'pageSize' => $pages->pageSize));
    }

    public function actionZobraz($id) {
        $criteria = new CDbCriteria;
        $criteria->condition = 'Id_zprava =' . $id . ' AND (Id_prijemce=' . Yii::app()->user->id . ' OR Id_odesilatele=' . Yii::app()->user->id . ')';
        $text = Zprava::model()->find($criteria);
        if ($text) {
            if ($text->Id_prijemce == Yii::app()->user->id){
                $text->Precteno = 1;
                $text->Prijemce = "nn";
                $text->save();
            }
            $this->renderPartial('zobraz', array('text' => $text));
        }
    }

    public function actionNova() {
        $model = new Zprava();
        if ($_POST) {
            if (Yii::app()->session['PRAVA']['Sys_Zpravy'] == 1 && isset($_POST['all'])) {
                $model->Id_prijemce = -1;
                $model->Typ_posty = 0;
                $model->Prijemce = "all";
            } else {
                $uzivatel = Uzivatel::model()->findByAttributes(array('Prezdivka' => $_POST['Zprava']['Prijemce']));
                if (!$uzivatel) {
                    Yii::app()->user->setFlash('badNick', 'Byla zadána neplatná přezdívka!');
                    Yii::app()->session['text'] = trim($_POST['Zprava']['Text']);
                    Yii::app()->session['predmet'] = $_POST['Zprava']['Predmet'];
                    $this->redirect(array('nova'));
                } else {
                    $model->Id_prijemce = $uzivatel->Id_uzivatel;
                }
            }
            if ($model->Id_prijemce) {
                $model->Datum_odeslani = date("Y-m-d H:i:s");
                $model->Id_odesilatele = Yii::app()->user->id;
                $model->attributes = $_POST['Zprava'];
                if ($model->save()) {
                    Yii::app()->session['text'] = "";
                    Yii::app()->session['predmet'] = "";
                    Yii::app()->user->setFlash('badNick', 'Zpráva byla úspěšně odeslána!');
                    $this->redirect(array('nova'));
                }
            }
        }
        $this->renderPartial('_form', array('model' => $model,));
    }

    public function actionOdpoved($id) {
        $model = new Zprava();
        $zprava = Zprava::model()->findByAttributes(array('Id_zprava' => $id));
        $uzivatel = Uzivatel::model()->findByAttributes(array('Id_uzivatel' => $zprava->Id_odesilatele));
        $this->renderPartial('_form', array('model' => $model, 'prepinac' => 1, 'predmet' => $zprava->Predmet, 'prijemce' => $uzivatel->Prezdivka));
    }

    public function actionSmazat($id) {
        $model = Zprava::model()->findByAttributes(array('Id_zprava' => $id));
        if ($model->Id_prijemce == Yii::app()->user->id) {
            $model->Smaz_prij = 1;
        }
        if ($model->Id_odesilatele == Yii::app()->user->id) {
            $model->Smaz_odes = 1;
        }
        $model->Prijemce = "nn";
        $model->save();
        echo 'Zpráva byla smazána.';
        return;
    }

}
