<?php

class UzivatelController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('registrace', 'captcha', 'AjaxValidate'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('update', 'view','admin', 'ban'),
                'users' => array('*'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('index', 'create', 'delete'),
                'roles' => array('1'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Declares class-based actions.
     */
    public function actions() {
        return array(
            // captcha action renders the CAPTCHA image displayed on the contact page
            'captcha' => array(
                'class' => 'CCaptchaAction',
                'backColor' => 0xFFFFFF,
            )
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] != '1') {
            // kontrola práv
            $this->render('view', array('model' => $this->loadModel(Yii::app()->user->id),));
        }
        //oprávnění editova všechny uživatele
        elseif (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] == '1') {
            $this->render('view', array('model' => $this->loadModel($id),));
        }
    }

    public function actionUpdate($id) {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] != '1') {
            // kontrola práv
            if ($id == Yii::app()->user->id) {
                $this->update($id);
                //nesplněná práva
            } else {
                $this->redirect(array('update', 'id' => Yii::app()->user->id));
            }
        }
        //oprávnění editova všechny uživatele
        elseif (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] == '1') {
            $this->update($id);
        }
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        $this->loadModel($id)->delete();
    }
    
    public function actionBan($id) {
        $uziv = $this->loadModel($id);
        if(Yii::app()->session['PRAVA']['Banovani_Uziv'] == '1'){
            if($uziv->Id_prava != '1'){
                if($uziv->aktivni == '1'){
                $uziv->aktivni = 0;
                }  else {
                    $uziv->aktivni = 1;
                }
                $uziv->save();
                $this->redirect(array('update', 'id' => $uziv->Id_uzivatel));
            }
        }
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] == '1') {
            $model = new Uzivatel('search');
            $model->unsetAttributes();  // clear any default values
            if (isset($_GET['Uzivatel']))
                $model->attributes = $_GET['Uzivatel'];

            $this->render('admin', array(
                'model' => $model,
            ));
        }else {
            $this->render('view', array('model' => $this->loadModel(Yii::app()->user->id),));
        }
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['EditaceVsech_Uziv'] == '1') {
            $model = new Uzivatel('search');
            $model->unsetAttributes();  // clear any default values
            if (isset($_GET['Uzivatel']))
                $model->attributes = $_GET['Uzivatel'];

            $this->render('admin', array(
                'model' => $model,
            ));
        }else {
            $this->render('view', array('model' => $this->loadModel(Yii::app()->user->id),));
        }
    }

    /**
     * Registruje uživatele
     */
    public function actionRegistrace() {
        $model = new Uzivatel('registrace');
        if (isset($_POST['Uzivatel'])) {
            $model->attributes = $_POST['Uzivatel'];
            if ($model->validate()) {
                $heslo = $this->randomPassword();
                $model->Heslo = $model->getHash($heslo);
                $model->Skore = 0;
                $datum = date("Y-m-d H:i:s");
                $model->Datum_registrace = $datum;
                $model->Novacek = 1;
                $model->dokoncena_registrace = 0;
                $model->aktivni = 1;
                $model->Id_prava = 2;
                $odesilatel = "info@test-game.g6.cz";
                $predmet = "Nová registrace ve hře TestGame";
                $zprava = "Dobrý den, děkujeme že jste se registrovali.\n Vaše heslo je: " . $heslo;
                $this->posliMail($odesilatel, $model->Email, $predmet, $zprava);
                Yii::app()->user->setFlash('regComplete', 'Děkujeme za registraci. Pro dokončení registrace se přihlašte.');

                if ($model->save()) {
                    $this->redirect(array('site/index'));
                }
            }
        }
        $this->render('registrace', array('model' => $model));
    }

    public function loadModel($id) {
        $model = Uzivatel::model()->with('prava')->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Validace formuláře
     */
    public function actionAjaxValidate() {
        header("Content-Type: text/javascript");
        if (isset($_GET['Email']) OR isset($_GET['Login'])) {
            switch ($_GET['s']) {
                case 1:
                    $login = htmlspecialchars($_GET['Login']);
                    $modelP = Uzivatel::model()->findByAttributes(array('Prezdivka' => $login));
                    if (isset($modelP)) {
                        echo "document.getElementById('ajaxP').innerHTML = 'Zadaná přezdívka je již registrována. Zvolte prosím jinou.';";
                    } else {
                        echo "document.getElementById('ajaxP').innerHTML = '';";
                    }
                    break;
                case 2:
                    $email = htmlspecialchars($_GET['Email']);
                    $modelE = Uzivatel::model()->findByAttributes(array('Email' => $email));
                    if (isset($modelE)) {
                        echo "document.getElementById('ajaxE').innerHTML = 'Zadaný E-mail je již registrován.';";
                    } else {
                        echo "document.getElementById('ajaxP').innerHTML = '';";
                    }
                    break;
                case 0:
                    $email = htmlspecialchars($_GET['Email']);
                    $modelE = Uzivatel::model()->findByAttributes(array('Email' => $email));
                    $login = htmlspecialchars($_GET['Login']);
                    $modelP = Uzivatel::model()->findByAttributes(array('Prezdivka' => $login));
                    if (isset($modelP)) {
                        echo "document.getElementById('ajaxP').innerHTML = 'Zadaná přezdívka je již registrována. Zvolte prosím jinou.';";
                    } elseif (isset($modelE)) {
                        echo "document.getElementById('ajaxE').innerHTML = 'Zadaný E-mail je již registrován.';";
                    } else {
                        echo "document.forms['uzivatel-registrace-form'].submit();\n";
                    }
                    break;
                default:
                    break;
            }
        } else {
            Yii::app()->end();
        }
    }

    /*
     * --------
     * Pomocné funkce
     * --------
     */

    /**
     * Performs the AJAX validation.
     * @param Uzivatel $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'uzivatel-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    /**
     * Uloží uživatele
     * @param type $id  id uživatele
     */
    protected function update($id) {
        $model = $this->loadModel($id);
        $this->performAjaxValidation($model);
        if (isset($_POST['Uzivatel'])) {
            $model->attributes = $_POST['Uzivatel'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->Id_uzivatel));
        }
        $this->render('update', array('model' => $model,));
    }

    /**
     * vytvoří náhodné heslo
     * @return type vrací heslo
     */
    private function randomPassword() {
        $alphabet = "abcdefghijklmnopqrstuwxyzABCDEFGHIJKLMNOPQRSTUWXYZ0123456789";
        $pass = array(); //remember to declare $pass as an array
        $alphaLength = strlen($alphabet) - 1; //put the length -1 in cache
        for ($i = 0; $i < 8; $i++) {
            $n = rand(0, $alphaLength);
            $pass[] = $alphabet[$n];
        }
        return implode($pass); //turn the array into a string
    }

    /**
     * Odešle email podel zadaných parametrů
     * @param type $from    od koho
     * @param type $to      pro koho
     * @param type $mail_subj   předmět zprávy
     * @param type $mail_txt    text zprávy
     */
    private function posliMail($from, $to, $mail_subj, $mail_txt) {
        $headers = '';
        $subject = "=?UTF-8?B?" . base64_encode($mail_subj) . "?=";
        $headers .= "From: $from\r\n" .
                "Return-Path: $from\r\n" .
                "MIME-Version: 1.0\r\n" .
                "Content-Type: text/plain; charset=\"UTF-8\"\r\n" .
                "Content-Transfer-Encoding: 8bit\r\n";
        Mail($to, $subject, $mail_txt, $headers);
    }

}
