<?php

class VerzeController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'archiv', 'view'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update', 'admin', 'delete'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['Sprava_Verzi'] == '1') {
            // kontrola práv
            $model = new Verze;
            if (isset($_POST['Verze'])) {
                $model->attributes = $_POST['Verze'];
                $model->Id_autor = Yii::app()->user->id;
                $model->Datum = new CDbExpression('NOW()');
                if ($model->save())
                    $this->redirect(array('view', 'id' => $model->Id));
            }

            $this->render('create', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    public function actionIndex() {
        $this->actionArchiv();
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        if (Yii::app()->session['PRAVA']['Sprava_Verzi'] == '1') {
            $model = $this->loadModel($id);

            // Uncomment the following line if AJAX validation is needed
            // $this->performAjaxValidation($model);

            if (isset($_POST['Verze'])) {
                $model->attributes = $_POST['Verze'];
                if ($model->save())
                    $this->redirect(array('view', 'id' => $model->Id));
            }

            $this->render('update', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['Sprava_Verzi'] == '1') {
            $this->loadModel($id)->delete();

            // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Lists all models.
     */
    public function actionArchiv() {
        
        $criteria = new CDbCriteria();
        $criteria->order = 'Id DESC';
        $criteria->with = 'uzivatel';

//Zjisti počet záznamů
        $count = Verze::model()->count($criteria);
//Nastav widget pro stránkování
        $pages = new CPagination($count);
        $pages->pageSize = Yii::app()->session['strankovani'];
        $pages->applyLimit($criteria);
//Načti data z DB
        $model = Verze::model()->findAll($criteria);

        $this->render('archiv', array('model' => $model, 'pages' => $pages, 'count' => $count, 'pageSize' => $pages->pageSize));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        // bez oprávnění editovat všechny uživatele
        if (Yii::app()->session['PRAVA']['Sprava_Verzi'] == '1') {
            $model = new Verze('search');
            $model->unsetAttributes();  // clear any default values
            if (isset($_GET['Verze']))
                $model->attributes = $_GET['Verze'];

            $this->render('admin', array(
                'model' => $model,
            ));
        }else {
            throw new CHttpException(403, 'Nedostatečná oprávnění!');
        }
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Verze the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Verze::model()->with('uzivatel')->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

}
