<?php

/**
 * This is the model class for table "uzivatel".
 *
 * The followings are the available columns in table 'uzivatel':
 * @property integer $Id_uzivatel
 * @property string $Jmeno
 * @property string $Prijmeni
 * @property string $Prezdivka
 * @property string $Email
 * @property string $Heslo
 * @property string $password_st
 * @property string $Popis
 * @property integer $Skore
 * @property string $Datum_registrace
 * @property integer $Novacek
 * @property integer $dokoncena_registrace
 * @property integer $Id_prava
 * @property integer $aktivni
 * @
 */
class Uzivatel extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $_oldPassword;
    public $password_st;
    public $EmailZ;
    public $licence;
    public $verifyCode;
    private $salt = "Bazpečné_Soleníčko";
    /*
     * 1 = dokončení registrace -> změna hesla (MestoController)
     */
    public $PREPINAC;

    public function tableName() {
        return 'uzivatel';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('Email, EmailZ, licence, Prezdivka' ,'required', 'on'=>'registrace'),
            array('Jmeno, Prijmeni, Prezdivka, Email, EmailZ', 'length', 'max' => 50),
            array('Heslo, password_st', 'length', 'max' => 80),
            array('Popis', 'safe'),
            array('Email, Prezdivka','unique'),
            array('Email, EmailZ', 'email'),
            array('licence', 'compare', 'compareValue' => true, 'on'=>'registrace', 'message' => 'Pro dokončení registrace musíte souhasit s podmínkami!' ),
            array('EmailZ', 'compare', 'compareAttribute'=>'Email', 'on'=>'registrace', 'message'=>'E-maily se musí shodovat!'),
            // Ověření CAPTCHA kódu
			      array('verifyCode', 'captcha', 'on'=>'registrace', 'allowEmpty'=>!CCaptcha::checkRequirements()),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('Id_uzivatel, Jmeno, Prijmeni, Prezdivka, Email, Popis, Skore, Datum_registrace, Novacek', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'prava' => array(self::BELONGS_TO, 'Prava', 'Id_prava'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'Id_uzivatel' => 'Id Uzivatel',
            'Jmeno' => 'Jméno',
            'Prijmeni' => 'Příjmení',
            'Prezdivka' => 'Přezdívka',
            'Email' => 'E-mail',
            'EmailZ' => 'E-mail znovu',
            'Heslo' => 'Nové heslo',
            'password_st' => 'Staré heslo',
            'Popis' => 'Popis',
            'Skore' => 'Skóre',
            'Datum_registrace' => 'Datum Registrace',
            'Novacek' => 'Nováček',
            'dokoncena_registrace' => 'Dokončena Registrace',
            'Id_prava' => 'Id Práva',
            'verifyCode'=>'Ověřovací kód:',
        );
    }

    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('Id_uzivatel', $this->Id_uzivatel);
        $criteria->compare('Jmeno', $this->Jmeno, true);
        $criteria->compare('Prijmeni', $this->Prijmeni, true);
        $criteria->compare('Prezdivka', $this->Prezdivka, true);
        $criteria->compare('Email', $this->Email, true);
        //$criteria->compare('Heslo', $this->Heslo, true);
        $criteria->compare('Popis', $this->Popis, true);
        $criteria->compare('Skore', $this->Skore);
        $criteria->compare('Datum_registrace', $this->Datum_registrace, true);
        $criteria->compare('Novacek', $this->Novacek);
        $criteria->compare('dokoncena_registrace', $this->dokoncena_registrace);
        $criteria->compare('Id_prava', $this->Id_prava);
        $criteria->compare('aktivni', $this->aktivni);
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Generuje z hesla HASH
     * @param type $password HEslo
     * @return type vrací hash z hesla
     */
    public function getHash($password){
        $options = array('cost' => 11);
        $hash = password_hash($password.$this->salt, PASSWORD_BCRYPT, $options);
        return $hash;
    }

    /**
     * Porovná heslo a Hash v DB
     * @param type $password
     * @return type
     */
    public function matchesPassword($password) {
        return password_verify($password.$this->salt, $this->_oldPassword);
    }

    /**
     * Fce, která se volá po vyhledání modelu
     * @return type
     */
    function afterFind() {
        if ($this->Datum_registrace == '0000-00-00') {
            $this->Datum_registrace = '';
        } else {
            $this->Datum_registrace = date("j.n.Y", strtotime($this->Datum_registrace));
        }
        $this->_oldPassword = $this->Heslo;
        $this->Heslo = '';
        return parent::afterFind();
    }

    /**
     * Fce volaná před uložením modelu
     * @return type
     */
    function beforeSave() {
        if (!$this->isNewRecord) {
            //Při Updatu kdy nebylo vyplněno heslo => Nechci změnu!!
            if (!$this->Heslo) {
                $this->Heslo = $this->_oldPassword;
                return parent::beforeSave();
            //Uživatel mění heslo => kontrola zdali je staré heslo správné
            }elseif ($this->matchesPassword($this->password_st)) {
                    $this->Heslo = $this->getHash($this->Heslo);
                    $this->password_st = '';
                    return parent::beforeSave();
            //Požadavek na změnu hesla v dokončování registrace        
            }elseif($this->PREPINAC == 1){
                    $this->PREPINAC = '';
                return parent::beforeSave();           
            }else {
                    $this->addError('password_st', 'Zadali jste špatné původní heslo!');
            }
        }else{
            //Pokud je nový záznam -> Registrace
            return parent::beforeSave();
            }
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Uzivatel the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
