<?php

/**
 * This is the model class for table "zprava".
 *
 * The followings are the available columns in table 'zprava':
 * @property integer $Id_zprava
 * @property integer $Id_prijemce
 * @property integer $Id_odesilatele
 * @property string $Predmet
 * @property string $Text
 * @property integer $Precteno
 * @property integer $Typ_posty
 * @property integer $Smaz_odes
 * @property integer $Smaz_prij
 * @property string $Datum_odeslani
 */
class Zprava extends CActiveRecord
{
    public $Prijemce;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'zprava';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Predmet, Text, Prijemce', 'required'),
			array('Id_prijemce, Id_odesilatele, Typ_posty, Smaz_odes, Smaz_prij', 'numerical', 'integerOnly'=>true),
			array('Predmet', 'length', 'max'=>50),
			array('Text', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('Id_zprava, Id_prijemce, Id_odesilatele, Predmet, Text, Precteno, Typ_posty, Smaz_odes, Smaz_prij, Datum_odeslani', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		return array(
            'odesilatel' => array(self::BELONGS_TO, 'Uzivatel', 'Id_odesilatele'),
            'prijemce'   => array(self::BELONGS_TO, 'Uzivatel', 'Id_prijemce'),
        );
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'Id_zprava' => 'Id Zprava',
			'Id_prijemce' => 'Id Prijemce',
			'Id_odesilatele' => 'Id Odesilatele',
			'Predmet' => 'Předmět',
			'Text' => 'Text',
			'Precteno' => 'Precteno',
			'Typ_posty' => 'Typ Posty',
			'Smaz_odes' => 'Smaz Odes',
			'Smaz_prij' => 'Smaz Prij',
			'Datum_odeslani' => 'Datum Odeslani',
                        'Prijemce' => 'Příjemce'
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('Id_zprava',$this->Id_zprava);
		$criteria->compare('Id_prijemce',$this->Id_prijemce);
		$criteria->compare('Id_odesilatele',$this->Id_odesilatele);
		$criteria->compare('Predmet',$this->Predmet,true);
		$criteria->compare('Text',$this->Text,true);
		$criteria->compare('Precteno',$this->Precteno);
		$criteria->compare('Typ_posty',$this->Typ_posty);
		$criteria->compare('Smaz_odes',$this->Smaz_odes);
		$criteria->compare('Smaz_prij',$this->Smaz_prij);
		$criteria->compare('Datum_odeslani',$this->Datum_odeslani,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Zprava the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
